# nucosCR 
*nucosCR* is a convenient cryptography module in python, works as a working toolbox for the module *pycrypto*.
This module is in alpha stage, any usage is on your own risk and responsibility.

## Install
```
pip install nucosCR
```
or download the tarball at [https://github.com/DocBO/nucosCR](https://github.com/DocBO/nucosCR), unzip and type
```
python setup.py install
```

## Documentation
[https://pythonhosted.org/nucosCR](https://pythonhosted.org/nucosCR)

## Recommended test runner
```
nose2 --plugin nose2.plugins.junitxml --junit-xml
```

## Licence
MIT License

## Platforms
No specific platform dependency. Python 2.7 should work as well as Python 3.4/3.5. Up to now only Linux OS is tested.
